@@ -1,6 +1,6 @@
 # Sys::HostAddr.pm
-# $Id: HostAddr.pm,v 0.96 2012/05/15 12:22:14 jkister Exp $
-# Copyright (c) 2010-2012 Jeremy Kister.
+# $Id: HostAddr.pm,v 0.99 2014/03/12 21:22:14 jkister Exp $
+# Copyright (c) 2010-2014 Jeremy Kister.
 # Released under Perl's Artistic License.
 
 package Sys::HostAddr;
@@ -10,7 +10,7 @@ use warnings;
 use IO::Socket::INET;
 use Sys::Hostname;
 
-our ($VERSION) = q$Revision: 0.96 $ =~ /(\d+\.\d+)/;
+our ($VERSION) = q$Revision: 0.99 $ =~ /(\d+\.\d+)/;
 my $ipv;
 
 
@@ -48,7 +48,7 @@ sub public {
     }
 
     my $sock = IO::Socket::INET->new(Proto => 'tcp',
-                                     PeerAddr => 'automation.whatismyip.com',     
+                                     PeerAddr => 'www.dnsbyweb.com',
                                      PeerPort => 80, 
                                      Timeout => 3);       
      
@@ -57,8 +57,8 @@ sub public {
     eval {
         local $SIG{ALRM} = sub { die "timeout during GET\n" };
         alarm(3);
-        print $sock "GET /n09230945.asp HTTP/1.1\r\n",                     
-                    "Host: automation.whatismyip.com\r\n",
+        print $sock "GET /mip.mpl HTTP/1.1\r\n",                     
+                    "Host: www.dnsbyweb.com\r\n",
                     "User-Agent: Sys::HostAddr/$VERSION (compatible; MSIE 8.0; ${platform}; Perl $])\r\n",  
                     "Accept: text/html; q=0.5, text/plain\r\n",
                     "Connection: close\r\n",
